@@ -1,20 +1,20 @@
 import logging
 from argparse import ArgumentParser, Namespace
-from typing import Sequence
+from typing import Sequence, cast
 
 from webknossos import Mag
+from webknossos.utils import get_executor_for_args
 
-from .cubing import create_parser as create_cubing_parser
-from .cubing import cubing, get_channel_and_sample_count_and_dtype
 from ._internal.utils import (
     add_isotropic_flag,
     add_sampling_mode_flag,
     get_channel_and_sample_iters_for_wk_compatibility,
-    get_executor_args,
     is_wk_compatible_layer_format,
     setup_logging,
     setup_warnings,
 )
+from .cubing import create_parser as create_cubing_parser
+from .cubing import cubing, get_channel_and_sample_count_and_dtype
 
 
 def create_parser() -> ArgumentParser:
@@ -55,7 +55,7 @@ def create_parser() -> ArgumentParser:
     )
     parser.add_argument(
         "--force_non_webknossos_format",
-        help="Specifies if the data should be converted, although webKnossos cannot read the result.",
+        help="Specifies if the data should be converted, although WEBKNOSSOS cannot read the result.",
         default=False,
         action="store_true",
     )
@@ -71,11 +71,11 @@ def _handle_hierarchical_data(args: Namespace, dtype: str, sample_count: int) ->
     if not is_wk_compatible_layer_format(sample_count, dtype):
         if args.force_non_webknossos_format:
             logging.warning(
-                "Chosen wkw format is incompatible with webKnossos. Proceeding anyways..."
+                "Chosen wkw format is incompatible with WEBKNOSSOS. Proceeding anyways..."
             )
         else:
             raise AssertionError(
-                "Chosen wkw format would not be compatible with webKnossos. If you wish to convert it anyway, use --force_wkw_format."
+                "Chosen wkw format would not be compatible with WEBKNOSSOS. If you wish to convert it anyway, use --force_wkw_format."
             )
 
 
@@ -90,7 +90,7 @@ def main(args: Namespace) -> None:
         args.source_path
     )
     if arg_dict.get("dtype") is not None:
-        dtype = args.get("dtype")
+        dtype = cast(str, arg_dict.get("dtype"))
 
     assert not (
         args.prefer_layers and args.prefer_channels
@@ -122,11 +122,11 @@ def main(args: Namespace) -> None:
             if not is_wk_compatible_layer_format(channel_count * sample_count, dtype):
                 if args.force_non_webknossos_format:
                     logging.warning(
-                        "Chosen wkw format is incompatible with webKnossos. Proceeding anyways..."
+                        "Chosen wkw format is incompatible with WEBKNOSSOS. Proceeding anyways..."
                     )
                 else:
                     raise AssertionError(
-                        "Chosen wkw format would not be compatible with webKnossos. If you wish to convert it anyway, use --force_wkw_format."
+                        "Chosen wkw format would not be compatible with WEBKNOSSOS. If you wish to convert it anyway, use --force_wkw_format."
                     )
             channel_iter = [None]
             sample_iter = [None]
@@ -144,44 +144,45 @@ def main(args: Namespace) -> None:
 
     layer_count = 0
     layers = []
-    for channel_index in channel_iter:
-        for sample_index in sample_iter:
-            layers.append(
-                cubing(
-                    args.source_path,
-                    args.target_path,
-                    f"{args.layer_name}_{layer_count}"
-                    if len(channel_iter) * len(sample_iter) > 1
-                    else args.layer_name,
-                    arg_dict.get("batch_size"),
-                    channel_index,
-                    sample_index,
-                    arg_dict.get("dtype"),
-                    args.target_mag,
-                    args.data_format,
-                    args.chunk_size,
-                    args.chunks_per_shard,
-                    args.interpolation_mode,
-                    args.start_z,
-                    args.skip_first_z_slices,
-                    args.pad,
-                    args.voxel_size,
-                    args,
+    with get_executor_for_args(args) as executor:
+        for channel_index in channel_iter:
+            for sample_index in sample_iter:
+                layers.append(
+                    cubing(
+                        args.source_path,
+                        args.target_path,
+                        f"{args.layer_name}_{layer_count}"
+                        if len(channel_iter) * len(sample_iter) > 1
+                        else args.layer_name,
+                        arg_dict.get("batch_size"),
+                        channel_index,
+                        sample_index,
+                        arg_dict.get("dtype"),
+                        args.target_mag,
+                        args.data_format,
+                        args.chunk_shape,
+                        args.chunks_per_shard,
+                        args.interpolation_mode,
+                        args.start_z,
+                        args.skip_first_z_slices,
+                        args.pad,
+                        args.voxel_size,
+                        executor=executor,
+                    )
                 )
+                layer_count += 1
+
+        for layer in layers:
+            if not args.no_compress:
+                layer.get_mag(args.target_mag).compress(executor=executor)
+
+            layer.downsample(
+                from_mag=args.target_mag,
+                coarsest_mag=None if args.max_mag is None else Mag(args.max_mag),
+                compress=not args.no_compress,
+                sampling_mode=args.sampling_mode,
+                executor=executor,
             )
-            layer_count += 1
-
-    for layer in layers:
-        if not args.no_compress:
-            layer.get_mag(args.target_mag).compress(args=args)
-
-        layer.downsample(
-            from_mag=args.target_mag,
-            max_mag=None if args.max_mag is None else Mag(args.max_mag),
-            compress=not args.no_compress,
-            sampling_mode=args.sampling_mode,
-            args=get_executor_args(args),
-        )
 
 
 if __name__ == "__main__":
