@@ -5,15 +5,15 @@ from pathlib import Path
 from typing import Any, Callable, Dict, Iterable, List, Optional, Set, Tuple, cast
 
 from webknossos.dataset.properties import LayerViewConfiguration
+from webknossos.utils import get_executor_for_args
 
 from ._internal.image_readers import image_reader
 from ._internal.utils import (
     add_data_format_flags,
-    add_voxel_size_flag,
     add_verbose_flag,
+    add_voxel_size_flag,
     find_files,
     get_channel_and_sample_iters_for_wk_compatibility,
-    get_executor_args,
     is_wk_compatible_layer_format,
     parse_path,
     setup_logging,
@@ -48,6 +48,15 @@ def create_parser() -> ArgumentParser:
         type=parse_path,
     )
 
+    parser.add_argument(
+        "--pad",
+        help="Automatically pad image files at the bottom and right borders. "
+        "Use this, when the input images don't have a common size, but have "
+        "their origin at (0, 0).",
+        default=False,
+        action="store_true",
+    )
+
     add_voxel_size_flag(parser)
     add_verbose_flag(parser)
     add_data_format_flags(parser)
@@ -229,8 +238,13 @@ class KnossosConverter(Converter):
                 # if the mag path is empty, we are already inside the mag folder, so there is only mag. We guess that this is mag 1.
                 if mag != "":
                     try:
-                        mag_int = int(mag)
+                        # Remove any potential mag prefixes
+                        mag_int_str = mag.replace("mag_", "").replace("mag", "")
+                        mag_int = int(mag_int_str)
                     except ValueError:
+                        logger.warning(
+                            f"Ignoring mag '{mag}' in '{layer_path}', because it could not be parsed"
+                        )
                         continue
                 else:
                     mag_int = 1
@@ -376,8 +390,6 @@ class ImageStackConverter(Converter):
         put_default_from_argparser_if_not_present(args, image_stack_parser, "pad")
         put_default_from_argparser_if_not_present(args, image_stack_parser, "verbose")
 
-        executor_args = get_executor_args(args)
-
         # detect layer and ds name
         (
             dataset_name,
@@ -408,44 +420,45 @@ class ImageStackConverter(Converter):
             )
 
             layer_count = 0
-            for channel_index in channel_iter:
-                for sample_index in sample_iter:
-                    if len(channel_iter) * len(sample_iter) > 1:
-                        curr_layer_name = f"{layer_name}_{layer_count}"
-                    else:
-                        curr_layer_name = layer_name
+            with get_executor_for_args(args) as executor:
+                for channel_index in channel_iter:
+                    for sample_index in sample_iter:
+                        if len(channel_iter) * len(sample_iter) > 1:
+                            curr_layer_name = f"{layer_name}_{layer_count}"
+                        else:
+                            curr_layer_name = layer_name
 
-                    arg_dict = vars(args)
-                    layer = cube_image_stack(
-                        Path(layer_path),
-                        args.target_path,
-                        curr_layer_name,
-                        arg_dict.get("batch_size"),
-                        channel_index,
-                        sample_index,
-                        arg_dict.get("dtype"),
-                        args.target_mag,
-                        args.data_format,
-                        args.chunk_size,
-                        args.chunks_per_shard,
-                        args.interpolation_mode,
-                        args.start_z,
-                        args.skip_first_z_slices,
-                        args.pad,
-                        args.voxel_size,
-                        executor_args,
-                    )
-
-                    if not is_wk_compatible_layer_format(sample_count, dtype):
-                        # This means that every sample has to be converted into its own layer, so we want to set a view configuration since first three layers are probably RGB
-                        color = ImageStackConverter.get_color_of_view_configuration(
-                            layer_count
+                        arg_dict = vars(args)
+                        layer = cube_image_stack(
+                            Path(layer_path),
+                            args.target_path,
+                            curr_layer_name,
+                            arg_dict.get("batch_size"),
+                            channel_index,
+                            sample_index,
+                            arg_dict.get("dtype"),
+                            args.target_mag,
+                            args.data_format,
+                            args.chunk_shape,
+                            args.chunks_per_shard,
+                            args.interpolation_mode,
+                            args.start_z,
+                            args.skip_first_z_slices,
+                            args.pad,
+                            args.voxel_size,
+                            executor=executor,
                         )
-                        if color is not None:
-                            layer.default_view_configuration = LayerViewConfiguration(
-                                color=color
+
+                        if not is_wk_compatible_layer_format(sample_count, dtype):
+                            # This means that every sample has to be converted into its own layer, so we want to set a view configuration since first three layers are probably RGB
+                            color = ImageStackConverter.get_color_of_view_configuration(
+                                layer_count
                             )
-                    layer_count += 1
+                            if color is not None:
+                                layer.default_view_configuration = (
+                                    LayerViewConfiguration(color=color)
+                                )
+                        layer_count += 1
 
         assert converted_layers > 0, "No layer could be converted!"
 
