@@ -1,10 +1,11 @@
 import logging
-from argparse import ArgumentParser, Namespace
+from argparse import ArgumentParser
 from os import path
 from pathlib import Path
 from typing import Any, List, Optional, Tuple, cast
 
 import numpy as np
+from cluster_tools import Executor
 from natsort import natsorted
 from webknossos import (
     COLOR_CATEGORY,
@@ -18,12 +19,12 @@ from webknossos import (
     Vec3Int,
     View,
 )
-from webknossos.dataset.defaults import DEFAULT_CHUNK_SIZE
 from webknossos.dataset._downsampling_utils import (
     InterpolationModes,
     downsample_unpadded_data,
     parse_interpolation_mode,
 )
+from webknossos.dataset.defaults import DEFAULT_CHUNK_SHAPE
 from webknossos.utils import time_start, time_stop
 
 from ._internal.image_readers import image_reader
@@ -32,8 +33,8 @@ from ._internal.utils import (
     add_data_format_flags,
     add_distribution_flags,
     add_interpolation_flag,
-    add_voxel_size_flag,
     add_verbose_flag,
+    add_voxel_size_flag,
     find_files,
     get_chunks,
     get_executor_for_args,
@@ -110,14 +111,14 @@ def create_parser() -> ArgumentParser:
         "-c",
         type=int,
         default=None,
-        help="Select a single channel to be cubed into a layer. This can be helpful if several channels should be converted to multiple data layers. Note that webKnossos only supports multiple channels if these are three uint8 channels. If this is not the case, use --channel_index to create a layer per channel.",
+        help="Select a single channel to be cubed into a layer. This can be helpful if several channels should be converted to multiple data layers. Note that WEBKNOSSOS only supports multiple channels if these are three uint8 channels. If this is not the case, use --channel_index to create a layer per channel.",
     )
 
     parser.add_argument(
         "--sample_index",
         type=int,
         default=None,
-        help="Select a single sample of a specific channel to be cubed into a layer. This option is only valid if channel_index is set. Since webKnossos only supports multiple uint8 channels, it may be necessary to cube a multi-sample dataset to different layers.",
+        help="Select a single sample of a specific channel to be cubed into a layer. This option is only valid if channel_index is set. Since WEBKNOSSOS only supports multiple uint8 channels, it may be necessary to cube a multi-sample dataset to different layers.",
     )
 
     add_voxel_size_flag(parser)
@@ -293,14 +294,14 @@ def cubing(
     dtype: Optional[str],
     target_mag_str: str,
     data_format: DataFormat,
-    chunk_size: Vec3Int,
+    chunk_shape: Vec3Int,
     chunks_per_shard: Vec3Int,
     interpolation_mode_str: str,
     start_z: int,
     skip_first_z_slices: int,
     pad: bool,
     voxel_size: Tuple[float, float, float],
-    executor_args: Namespace,
+    executor: Executor,
 ) -> Layer:
     source_files = find_source_filenames(source_path)
 
@@ -350,7 +351,7 @@ def cubing(
         dtype = image_reader.read_dtype(source_files[0])
 
     if batch_size is None:
-        batch_size = DEFAULT_CHUNK_SIZE.z
+        batch_size = DEFAULT_CHUNK_SHAPE.z
 
     target_mag = Mag(target_mag_str)
 
@@ -383,7 +384,7 @@ def cubing(
     target_mag_view = target_layer.get_or_add_mag(
         target_mag,
         chunks_per_shard=chunks_per_shard,
-        chunk_size=chunk_size,
+        chunk_shape=chunk_shape,
     )
 
     interpolation_mode = parse_interpolation_mode(
@@ -396,36 +397,35 @@ def cubing(
 
     logging.info("Found source files: count={} size={}x{}".format(num_z, num_x, num_y))
 
-    with get_executor_for_args(executor_args) as executor:
-        job_args = []
-        # We iterate over all z sections
-        for z in range(skip_first_z_slices, num_z, DEFAULT_CHUNK_SIZE.z):
-            # The z is used to access the source files. However, when writing the data, the `start_z` has to be considered.
-            max_z = min(num_z, z + DEFAULT_CHUNK_SIZE.z)
-            # Prepare source files array
-            if len(source_files) > 1:
-                source_files_array = source_files[z:max_z]
-            else:
-                source_files_array = source_files * (max_z - z)
+    job_args = []
+    # We iterate over all z sections
+    for z in range(skip_first_z_slices, num_z, DEFAULT_CHUNK_SHAPE.z):
+        # The z is used to access the source files. However, when writing the data, the `start_z` has to be considered.
+        max_z = min(num_z, z + DEFAULT_CHUNK_SHAPE.z)
+        # Prepare source files array
+        if len(source_files) > 1:
+            source_files_array = source_files[z:max_z]
+        else:
+            source_files_array = source_files * (max_z - z)
 
-            # Prepare job
-            job_args.append(
-                (
-                    target_mag_view.get_view(
-                        (0, 0, z + start_z),
-                        (num_x, num_y, max_z - z),
-                    ),
-                    target_mag,
-                    interpolation_mode,
-                    source_files_array,
-                    batch_size,
-                    pad,
-                    channel_index,
-                    sample_index,
-                    dtype,
-                    target_layer.num_channels,
-                )
+        # Prepare job
+        job_args.append(
+            (
+                target_mag_view.get_view(
+                    (0, 0, z + start_z),
+                    (num_x, num_y, max_z - z),
+                ),
+                target_mag,
+                interpolation_mode,
+                source_files_array,
+                batch_size,
+                pad,
+                channel_index,
+                sample_index,
+                dtype,
+                target_layer.num_channels,
             )
+        )
 
         largest_segment_id_per_chunk = wait_and_ensure_success(
             executor.map_to_futures(cubing_job, job_args),
@@ -448,22 +448,23 @@ if __name__ == "__main__":
 
     arg_dict = vars(args)
 
-    cubing(
-        args.source_path,
-        args.target_path,
-        args.layer_name,
-        arg_dict.get("batch_size"),
-        arg_dict.get("channel_index"),
-        arg_dict.get("sample_index"),
-        arg_dict.get("dtype"),
-        args.target_mag,
-        args.data_format,
-        args.chunk_size,
-        args.chunks_per_shard,
-        args.interpolation_mode,
-        args.start_z,
-        args.skip_first_z_slices,
-        args.pad,
-        args.voxel_size,
-        args,
-    )
+    with get_executor_for_args(args) as executor:
+        cubing(
+            args.source_path,
+            args.target_path,
+            args.layer_name,
+            arg_dict.get("batch_size"),
+            arg_dict.get("channel_index"),
+            arg_dict.get("sample_index"),
+            arg_dict.get("dtype"),
+            args.target_mag,
+            args.data_format,
+            args.chunk_shape,
+            args.chunks_per_shard,
+            args.interpolation_mode,
+            args.start_z,
+            args.skip_first_z_slices,
+            args.pad,
+            args.voxel_size,
+            executor=executor,
+        )
