@@ -19,7 +19,7 @@ from ._internal.utils import (
 )
 
 WKW_CUBE_REGEX = re.compile(
-    fr"z(\d+){re.escape(sep)}y(\d+){re.escape(sep)}x(\d+)(\.wkw)$"
+    rf"z(\d+){re.escape(sep)}y(\d+){re.escape(sep)}x(\d+)(\.wkw)$"
 )
 
 
@@ -92,7 +92,7 @@ def write_webknossos_metadata(
     if name == None:
         name = dataset_path.name
 
-    # Generate a metadata file for webKnossos
+    # Generate a metadata file for WEBKNOSSOS
     # Currently includes no source of information for team
     layers = list(
         detect_layers(
